Installation
============

Download code
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
https://github.com/andreatramacere/oda_api/archive/1.0.0.tar.gz

Installation
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
1) PIP
    .. code-block:: bash

        - pip install oda-api

2) Anaconda
     .. code-block:: bash

        - conda install -c conda-forge --file requirements.txt
        - python setup.py install

